/*
 //  Controller.h
 //  FMenu
 //
 //  Created by Logan Rockmore on 12/16/06.
 Contributors:	Logan Rockmore
				Paul Borokhov
 //  Copyright 2006 by Contributors, 2007-9 by Paul Borokhov. All rights reserved.
 //
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * FMenu is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#import <Cocoa/Cocoa.h>
#import <MKAbeFook/MKAbeFook.h>
#import <GNotifier.h>
#import <AppKit/NSMenu.h>
#import <ComboArray.h>
#import <GenericIDS.h>
#import <FB_URLs.h>
#import <Downloader.h>
#import <SystemConfiguration/SCNetworkReachability.h>
#import <Sparkle/Sparkle.h>


void networkStatusDidChange(SCNetworkReachabilityRef name, SCNetworkConnectionFlags flags, void * infoDictionary);

@interface Controller : NSObject {
	@private
	MKFacebook* facebook;
	SCNetworkReachabilityRef facebookName;
	BOOL isReachable;

	NSStatusItem* statusItem;
	IBOutlet NSMenu* statusItemMenu;
	
	GNotifier* growl;
	
	NSTimer* timer;
	
	NSXMLDocument *oldData;
	NSMutableArray *namesArray;
	NSMutableArray *eventsArray;
	NSMutableArray *groupsArray;
	NSMutableArray *quicklaunchArray;
	NSMutableDictionary *namesDic;
	NSMutableDictionary *eventsDic;
	NSMutableDictionary *groupsDic;
	NSMutableDictionary *idDic;
	
	unsigned char noOfChecks;
	unsigned char initialDelay;
	unsigned char firstSleepInterval;
	unsigned char errorSleepTime;
	NSString *apikey;
	NSString *secret;
	NSString *loggedInImageName;
	NSString *loggedInImageNameInv;
	NSString *loggedOutImageName;
	NSString *loggedOutImageNameInv;
	NSString *sleepingImageName;
	NSString *growlID;
	unsigned char nameIndex;
	unsigned char startIndex;
	unsigned char whoseTurn;
	unsigned short currentCount;
	int unreadMessages;
	int unreadPokes;
	unsigned short eventCount;
	unsigned short friendRequestsCount;
	int wallPosts;
	unsigned short totalUnread;
	NSArray *fields;
	BOOL sleeping;
	NSString *pokesLastID, *messagesLastID;
	
	// Menu Items
	IBOutlet NSMenuItem* usersNameMenuItem;
	IBOutlet NSMenuItem* unreadMessagesMenuItem;
	IBOutlet NSMenuItem* totalMessagesMenuItem;
	IBOutlet NSMenuItem* unseenPokesMenuItem;
	IBOutlet NSMenuItem* totalPokesMenuItem;
	IBOutlet NSMenuItem* upcomingEventsMenuItem;
	IBOutlet NSMenuItem* totalEventsMenuItem;
	IBOutlet NSMenuItem* friendRequestsMenuItem;
	IBOutlet NSMenuItem* friendsMenuItem;
	IBOutlet NSMenuItem* friendsNotesMenuItem;
	
	IBOutlet NSMenuItem* wallPostsMenuItem;
	
	IBOutlet NSMenuItem* forceUpdateMenuItem;
	IBOutlet NSMenuItem* quickLaunchMenuItem;
	IBOutlet NSMenuItem* resetMenuItem;
	
	// User's home submenu items
	IBOutlet NSMenuItem* notesMenuItem;
	IBOutlet NSMenuItem* photosMenuItem;
	IBOutlet NSMenuItem* sharesMenuItem;
	IBOutlet NSMenuItem* groupsMenuItem;
	
	// About Window
	IBOutlet NSWindow *aboutWindow;
	IBOutlet NSTextField *aboutVersionTextField;
	
	// Read Me
	IBOutlet NSWindow *readMeWindow;
	IBOutlet NSTextView *readMeView;
	
	// Preferences window
	IBOutlet NSWindow *preferencesWindow;
	IBOutlet NSTabView *prefsTabView;
	IBOutlet NSView *initialFocusItem;
	IBOutlet NSTextField *refreshInterval;
	IBOutlet NSTextField *timerExplanation;
	IBOutlet NSButton *openGrowl;
	
	// Search Panel
	IBOutlet NSPanel *quickLaunchPanel;
	IBOutlet NSComboBox *nameSearch;
	@public
}

#pragma mark -
#pragma mark Startup
+ (void)initialize;
- (id) init;
- (void)awakeFromNib;
- (void)initFacebook;
- (void)userLoginSuccessful;

#pragma mark App Methods
- (IBAction)goToFriendProfile:(id)sender;
- (void)checkForUpdates:(NSTimer*)theTimer;
- (void)setInitialAvailability;
- (BOOL)checkAvailability;
- (void)setReachable:(BOOL)value;

#pragma mark "Delegate" methods
- (void)setMenuImage:(id)sender;
- (void)setLoginMenuItemText;
- (void)menuNeedsUpdate:(NSMenu *)menu;
- (void)windowDidClose:(NSNotification *)aNotification;
- (void)windowDidBecomeKey:(NSNotification *)aNotification;
- (void)applicationWillTerminate:(NSNotification *)aNotification;
- (SUAppcastItem *)bestValidUpdateInAppcast:(SUAppcast *)appcast forUpdater:(SUUpdater *)bundle;

@end